@@ -23,7 +23,7 @@ class GetMediaShowItemView(BrowserView):
         else:
             title = ""
         
-        if hasattr(self.context, "description"):
+        if hasattr(self, "description"):
             description = self.context.description
         elif hasattr(self.context, "Description"):
             description = self.context.Description()
@@ -43,7 +43,7 @@ class GetMediaShowItemView(BrowserView):
             return jsonStr
         
     def sanitizeStringForJson(self, str):
-        str = str.replace("\n", " ").replace('"', '\\"');
+        str = str.replace("\n", " ").replace('"', '\\"').replace();
         return str
      
     def getMediaURL(self):
